@@ -86,7 +86,7 @@ class DebhelperTests(unittest.TestCase):
         '''ensure assert when there is a typo in the script path or doesn't exist'''
         os.remove(os.path.join(self.pkgdir, "script1.sh"))
         stdout = self.buildpackage(self.env)
-        self.assertTrue("dh_migrations: install -p -m755 script1.sh debian/vanilla/usr/share/session-migration/scripts returned exit code 1" in stdout)
+        self.assertTrue("dh_migrations: error: install -p -m755 script1.sh debian/vanilla/usr/share/session-migration/scripts returned exit code 1" in stdout)
 
 
 if __name__ == '__main__':
